@@ -8,13 +8,15 @@ __path__ = extend_path(__path__, __name__)  # type: ignore
 
 from ngdi.nebula_reader import NebulaReader
 from ngdi.nebula_writer import NebulaWriter
-from ngdi.nebula_algo import NebulaAlgo
+from ngdi.nebula_algo import NebulaAlgorithm
 from ngdi.nebula_gnn import NebulaGNN
+from ngdi.config import NebulaGraphConfig
 
 # export
 __all__ = (
     "NebulaReader",
     "NebulaWriter",
-    "NebulaAlgo",
+    "NebulaAlgorithm",
     "NebulaGNN",
+    "NebulaGraphConfig",
 )
